summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/irc/ircchannelcontact.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/protocols/irc/ircchannelcontact.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/irc/ircchannelcontact.h')
-rw-r--r--kopete/protocols/irc/ircchannelcontact.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/kopete/protocols/irc/ircchannelcontact.h b/kopete/protocols/irc/ircchannelcontact.h
index 15a72e17..0febd30b 100644
--- a/kopete/protocols/irc/ircchannelcontact.h
+++ b/kopete/protocols/irc/ircchannelcontact.h
@@ -49,50 +49,50 @@ class IRCChannelContact
Q_OBJECT
public:
- IRCChannelContact(IRCContactManager *, const QString &channel, Kopete::MetaContact *metac);
+ IRCChannelContact(IRCContactManager *, const TQString &channel, Kopete::MetaContact *metac);
~IRCChannelContact();
/**
* Returns the current topic for this channel.
*/
- const QString &topic() const { return mTopic; };
+ const TQString &topic() const { return mTopic; };
/* Set password for a channel */
- void setPassword(const QString &password) { mPassword = password; }
+ void setPassword(const TQString &password) { mPassword = password; }
/* Get password for a channel */
- const QString &password() const { return mPassword; }
+ const TQString &password() const { return mPassword; }
/**
* Returns if a mode is enabled for this channel.
* @param mode The mode you want to check ( 't', 'n', etc. )
* @param value This is a pointer to a QString which is set to
* the value of the mode if it has one. Example, the mode 'l' or
* the mode 'k'. If the mode has no such value then the pointer
* is always returned null.
*/
- bool modeEnabled( QChar mode, QString *value = 0 );
+ bool modeEnabled( TQChar mode, TQString *value = 0 );
// Kopete::Contact stuff
- virtual QPtrList<KAction> *customContextMenuActions();
- virtual const QString caption() const;
+ virtual TQPtrList<KAction> *customContextMenuActions();
+ virtual const TQString caption() const;
//Methods handled by the signal mapper
- void userJoinedChannel(const QString &user);
- void userPartedChannel(const QString &user, const QString &reason);
- void userKicked(const QString &nick, const QString &nickKicked, const QString &reason);
- void channelTopic(const QString &topic);
- void channelHomePage(const QString &url);
- void topicChanged(const QString &nick, const QString &newtopic);
- void topicUser(const QString &nick, const QDateTime &time);
- void namesList(const QStringList &nicknames);
+ void userJoinedChannel(const TQString &user);
+ void userPartedChannel(const TQString &user, const TQString &reason);
+ void userKicked(const TQString &nick, const TQString &nickKicked, const TQString &reason);
+ void channelTopic(const TQString &topic);
+ void channelHomePage(const TQString &url);
+ void topicChanged(const TQString &nick, const TQString &newtopic);
+ void topicUser(const TQString &nick, const TQDateTime &time);
+ void namesList(const TQStringList &nicknames);
void endOfNames();
- void incomingModeChange(const QString &nick, const QString &mode);
- void incomingChannelMode(const QString &mode, const QString &params );
+ void incomingModeChange(const TQString &nick, const TQString &mode);
+ void incomingChannelMode(const TQString &mode, const TQString &params );
void failedChankey();
void failedChanBanned();
void failedChanInvite();
void failedChanFull();
- void newAction(const QString &from, const QString &action);
+ void newAction(const TQString &from, const TQString &action);
public slots:
void updateStatus();
@@ -101,13 +101,13 @@ public slots:
* Sets the topic of this channel
* @param topic The topic you want set
*/
- void setTopic( const QString &topic = QString::null );
+ void setTopic( const TQString &topic = TQString::null );
/**
* Sets or unsets a mode on this channel
* @param mode The full text of the mode change you want performed
*/
- void setMode( const QString &mode = QString::null );
+ void setMode( const TQString &mode = TQString::null );
void part();
void partAction();
@@ -116,17 +116,17 @@ public slots:
protected slots:
void chatSessionDestroyed();
- virtual void privateMessage(IRCContact *from, IRCContact *to, const QString &message);
+ virtual void privateMessage(IRCContact *from, IRCContact *to, const TQString &message);
virtual void initConversation();
private slots:
- void slotIncomingUserIsAway( const QString &nick, const QString &reason );
+ void slotIncomingUserIsAway( const TQString &nick, const TQString &reason );
void slotModeChanged();
void slotAddNicknames();
void slotConnectedToServer();
void slotUpdateInfo();
void slotHomepage();
- void slotChannelListed(const QString &channel, uint members, const QString &topic);
+ void slotChannelListed(const TQString &channel, uint members, const TQString &topic);
void slotOnlineStatusChanged(Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus);
private:
@@ -143,13 +143,13 @@ private:
KToggleAction *actionModeI; // Invite Only
KToggleAction *actionModeM; // Moderated
- QString mTopic;
- QString mPassword;
- QStringList mJoinedNicks;
- QMap<QString, bool> modeMap;
- QTimer *mInfoTimer;
+ TQString mTopic;
+ TQString mPassword;
+ TQStringList mJoinedNicks;
+ TQMap<TQString, bool> modeMap;
+ TQTimer *mInfoTimer;
- void toggleMode( QChar mode, bool enabled, bool update );
+ void toggleMode( TQChar mode, bool enabled, bool update );
void toggleOperatorActions( bool enabled );
};
@@ -49,50 +49,50 @@ class IRCChannelContact
* Returns if a mode is enabled for this channel.
* @param mode The mode you want to check ( 't', 'n', etc. )
- * @param value This is a pointer to a QString which is set to
+ * @param value This is a pointer to a TQString which is set to
* the value of the mode if it has one. Example, the mode 'l' or
* the mode 'k'. If the mode has no such value then the pointer